==> haskell-hslua-module-version-1.1.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-C3Lxh15CRYDIcEvlxSD3Zw
key:                  hslua-module-version-1.1.1-C3Lxh15CRYDIcEvlxSD3Zw
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  2785e26ebac22b0e5323292254b9baad
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-C3Lxh15CRYDIcEvlxSD3Zw
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-8vREXfYFhyiIPYIDeUQxEK
    hslua-marshalling-2.3.1-DIOGJ7ojaMY41as1vYyNO8
    hslua-packaging-2.3.1-51qAamebjPxK6IKONaFTdT text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-version-1.1.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-2bSDj10EOxtDM3AVCFnoxH
key:                  hslua-module-version-1.1.1-2bSDj10EOxtDM3AVCFnoxH
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  334c123c97f93066370c194e4c64f150
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-2bSDj10EOxtDM3AVCFnoxH
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-G0p4pDEAuRC9egDZNBd3TZ
    hslua-marshalling-2.3.1-1VequITq5GO81sRAuF35hQ
    hslua-packaging-2.3.1-gfdCfMkm5EGyR86RUIiCQ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
